Generating Cold Start Slot Filling Variant Runs (August 18, 2015)
==================================================

## Requirements
You will need:

* Your slot filling system (we will call your SF system `SFSystem1`).
* The top-level evaluation queries. In this example we use `SimpsonsQuery.xml` (which is distributed with the sample collection).
* The query generating script `CS-GenerateQueries.pl`.
* The packaging script `CS-PackageOutput.pl`.
* The validation script `CS-ValidateSF.pl`.
      * (Optional) The file to be used with the validator's `-docs`
        flag to ensure that all offsets in a submission are legal with
        respect to the source document collection. In this example we
        use `SimpsonsDocumentLengths.tab.txt`

The above three scripts are available from the TAC KBP Web Site under Cold Start KBP->Tools.

## Creating round #1 submission file `SF-output-round1.txt`
### Step 1: Create query file for round #1 `SimpsonsQuery_r1.xml`

First, create the query file for round #1 using `CS-GenerateQueries.pl` script (which we will call `SimpsonsQuery_r1.xml`). Running the query generating script with the -h flag (or with no arguments) will show its usage:

~~~
perl CS-GenerateQueries.pl -h
CS-GenerateQueries.pl:  Generate a query file for a Cold Start Slot Filling
                        variant submission. With two arguments, it updates the
                        input queries with the <slot> field. With three
                        arguments it generates a second round query file based
                        on the first round slot filling output.

Usage: CS-GenerateQueries.pl {-switch {-switch ...}} queryfile outputfile {runfile}

Legal switches are:
  -docs <value>        Tab-separated file containing docids and document
                         lengths, measured in unnormalized Unicode characters
  -error_file <value>  Specify a file to which error output should be redirected
                         (Default = STDERR).
  -help                Show help
  -valid               Ensure valid XML output by escaping angle brackets and
                         ampersands
  -version             Print version number and exit
parameters are:
  queryfile   File containing queries used to generate the file being validated
                (Required).
  outputfile  File into which new queries are to be placed. (Required).
  runfile     File containing query output. Omit to generate initial queries.
~~~

So to generate round #1 queries, you might use the following:

~~~
perl CS-GenerateQueries.pl SimpsonsQuery.xml \
	SimpsonsQuery_r1.xml
~~~

Notice that for round #1, you pass only two arguments to `CS-GenerateQueries.pl`.

This will produce round #1 queries file called `SimpsonsQuery_r1.xml`.

### Step 2: Run your SF system over the round #1 queries 

Run your SF system using round #1 queries file `SimpsonsQuery_r1.xml` saving the output in `SF-output-round1.txt`.


## Creating round #2 submission file `SF-output-round2.txt`
### Step 1: Create query file for round #2 `SimpsonsQuery_r2.xml`

Next, we create the query file for round #2 using the same script (`CS-GenerateQueries.pl`) that we used to generate the query file for round #1. This time we provide the script with a third argument, which is the result of applying your SF system to the round #1 query file (i.e., `SF-output-round1.txt`). 

So to generate round #2 queries, you might use the following:

~~~
perl CS-GenerateQueries.pl SimpsonsQuery.xml \
	SimpsonsQuery_r2.xml \
	SF-output-round1.txt
~~~

This will produce round #2 queries file called `SimpsonsQuery_r2.xml`.

### Step 2: Run your SF system over the round #2 queries 

Run your SF system using round #2 queries file `SimpsonsQuery_r2.xml` saving the output in `SF-output-round2.txt`.


## Generate the submission file

Now that you have the SF output files for the two rounds, you can run packaging script to combine the two and produce the submission file using the packaging script. Running the packaging script with the -h flag (or with no arguments) will show its usage:

~~~
perl CS-PackageOutput.pl -h
CS-PackageOutput.pl:  Marshal round 1 and round 2 output for the Cold Start 2014
                      Slot Filling variant.

Usage: CS-PackageOutput.pl {-switch {-switch ...}} queryfile round1file round2file outputfile

Legal switches are:
  -docs <value>        Tab-separated file containing docids and document
                         lengths, measured in unnormalized Unicode characters
  -error_file <value>  Specify a file to which error output should be redirected
                         (Default = STDERR).
  -help                Show help
  -version             Print version number and exit
parameters are:
  queryfile   File containing queries used to generate the file being validated.
                Only the original query file needs to be specified here
                (Required).
  round1file  File containing round 1 output (Required).
  round2file  File containing round 2 output (Required).
  outputfile  File into which to place combined output (Required).
~~~

So to generate the submission file, you might use the following:

~~~
perl CS-PackageOutput.pl \
	SimpsonsQuery.xml \
	SF-output-round1.txt \
	SF-output-round2.txt \
	submission-file.txt
~~~

This will produce the submission file `submission-file.txt` that you would submit after validation.

To validate the submission file you might use the following:

~~~
perl CS-ValidateSF.pl \
        -docs SimpsonsDocumentLengths.tab.txt
	SimpsonsQuery.xml
	submission-file.txt
~~~
